# 📖 Summary
- [📖 Summary](#📖-summary)
- [💼 About Greenhouse](#💼-about-greenhouse)
  - [😍 Why is it a big deal for Greenhouse customers & partners?](#😍-why-is-it-a-big-deal-for-greenhouse-customers--partners)
- [🔧 How does it work?](#🔧-how-does-it-work)
  - [📊 Data integration capabilities:](#📊-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#🧠-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#🔌-connector-actions)
- [💍 Quick Start Examples](#💍-quick-start-examples)
- [🔗 Useful Links](#🔗-useful-links)
- [👏 Special Thanks](#👏-special-thanks)


# 💼 About Greenhouse

> Greenhouse is an applicant tracking system and recruitment software that helps companies manage and streamline their hiring process. It includes features such as job posting, candidate tracking, scheduling interviews, and offer management.  Greenhouse also provides analytics and reporting to help companies track the effectiveness of their recruitment process. It also offers an API to help companies integrating it with other internal systems.

<p align="center">
<image src=https://user-images.githubusercontent.com/113343504/215117041-ebbc3963-5fbe-4706-b9c7-97882680fac0.png
 width=90% height=100% >
</p>

## 😍 Why is it a big deal for Greenhouse customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Greenhouse customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Greenhouse customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Greenhouse to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Greenhouse.
- ⬅️ Send Jobs data from Greenhouse to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Greenhouse.



<p align="center">
<image src=https://github.com/user-attachments/assets/06cafa10-de38-40d8-b153-2148f5e0a06b width=90% height=100% >
</p>

## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Greenhouse**)


# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Create jobs in hrflow**](docs/create_jobs_in_hrflow.md) | Send **created** 'job(s)' _from_  _to_ HrFlow |
| [**Update jobs in hrflow**](docs/update_jobs_in_hrflow.md) | Send **updated** 'job(s)' _from_  _to_ HrFlow |
| [**Archive jobs in hrflow**](docs/archive_jobs_in_hrflow.md) | Send **archived** 'job(s)' _from_  _to_ HrFlow |
| [**Create profiles in hrflow**](docs/create_profiles_in_hrflow.md) | Send **created** 'profile(s)' _from_  _to_ HrFlow |
| [**Update profiles in hrflow**](docs/update_profiles_in_hrflow.md) | Send **updated** 'profile(s)' _from_  _to_ HrFlow |
| [**Archive profiles in hrflow**](docs/archive_profiles_in_hrflow.md) | Send **archived** 'profile(s)' _from_  _to_ HrFlow |
| [**Create profiles in **](docs/create_profiles_in_.md) | Send **created** 'profile(s)' _from_ HrFlow _to_  |
| [**Update profiles in **](docs/update_profiles_in_.md) | Send **updated** 'profile(s)' _from_ HrFlow _to_  |
| [**Archive profiles in **](docs/archive_profiles_in_.md) | Send **archived** 'profile(s)' _from_ HrFlow _to_  |


</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :

<p align="center">
<image src=https://user-images.githubusercontent.com/107410704/219013506-7fb78971-ee1e-4374-8d89-6956034093c3.png width=90% height=100% >
</p>

Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄 Visit [Greenhouse](https://www.greenhouse.io/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/v2/connectors/greenhouse) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai : XXXXX YYYYY - Software Engineer
- 🤝 Greenhouse : XXXXX YYYYY - Partner Manager